@@ -27,12 +27,14 @@ import platform
 import re
 import time
 from math import floor
+from os.path import join as pjoin
+from os.path import normpath
 
 from snakeoil import process
-from snakeoil.bash import iter_read_bash
+from snakeoil.bash import read_bash
 from snakeoil.compatibility import IGNORED_EXCEPTIONS
 from snakeoil.fileutils import touch
-from snakeoil.osutils import ensure_dirs, listdir_files, normpath, pjoin
+from snakeoil.osutils import ensure_dirs, listdir_files
 from snakeoil.process import spawn
 
 from .. import os_data
@@ -294,7 +296,7 @@ class ldconfig(base):
         fp = self.ld_so_path(offset)
 
         try:
-            l = [x.lstrip(os.path.sep) for x in iter_read_bash(fp)]
+            l = [x.lstrip(os.path.sep) for x in read_bash(fp)]
         except FileNotFoundError:
             self._mk_ld_so_conf(fp)
             # fall back to an educated guess.
@@ -619,7 +621,9 @@ class BlockFileType(base):
         file_typer = file_type.file_identifier()
 
         if self.filter_regex is None:
-            filter_re = lambda x: True
+
+            def filter_re(x):
+                return True
         else:
             filter_re = re.compile(self.filter_regex).match
         bad_pat = re.compile(self.bad_regex).match
